@@ -3,7 +3,7 @@ package App::ZofCMS::Plugin::BasicLWP;
 use warnings;
 use strict;
 
-our $VERSION = '0.0102';
+our $VERSION = '0.0103';
 
 use LWP::UserAgent;
 use base 'App::ZofCMS::Plugin::Base';
@@ -113,7 +113,12 @@ on the fetched data, make sure to set correct priorities.
     }
 
 The plugin won't run unless C<plug_basic_lwp> first-level key is present either in Main
-Config File or ZofCMS Template. Takes a hashref as a value. If the same keys are specified
+Config File or ZofCMS Template. Takes a hashref or a subref as a value. If subref is
+specified,
+its return value will be assigned to C<plug_basic_lwp> as if it was already there. If sub returns
+an C<undef>, then plugin will stop further processing. The C<@_> of the subref will
+contain (in that order): ZofCMS Tempalate hashref, query parameters hashref and
+L<App::ZofCMS::Config> object. If the same keys are specified
 in both Main Config File and ZofCMS Template, then the value set in ZofCMS template will
 take precedence. The possible keys/values of that hashref are as follows:
 
